/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BaseTaglet.java 23 2006-02-22 14:10:17Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.taglets;

import com.sun.javadoc.Tag;
import com.sun.tools.doclets.Taglet;

/**
 * This is a base taglet to document tests.
 * Example: @toto the toto is magic.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class BaseTaglet implements Taglet{

    /**
     * Tag literal.
     */
    private String strName = null;


    /**
     *
     * @param name tag name. Example: tag = @toto, name = toto.
     */
    public BaseTaglet(final String name){
        strName = name;
    }

    /**
     * Will return false. The <code>@tagName</code> can't be used in field documentation.
     * @return true since <code>@tagName</code>
     * can be used in field documentation and false
     * otherwise.
     */
    public boolean inField() {
        return true;
    }

    /**
     * Will return true. The <code>@tagName</code>
     * can be used in constructor documentation.
     * @return true since <code>@tagName</code>
     * can be used in constructor documentation and false
     * otherwise.
     */
    public boolean inConstructor() {
        return true;
    }

    /**
     * Will return true. The <code>@tagName</code> can be used in method documentation.
     * @return true since <code>@tagName</code>
     * can be used in method documentation and false
     * otherwise.
     */
    public boolean inMethod() {
        return true;
    }

    /**
     * Will return true. The <code>@tagName</code> can be used in overview documentation.
     * @return true since <code>@tagName</code>
     * can be used in method documentation and false
     * otherwise.
     */
    public boolean inOverview() {
        return true;
    }

    /**
     * Will return true. The <code>@tagName</code> can be used in package documentation.
     * @return true since <code>@tagName</code>
     * can be used in method documentation and false
     * otherwise.
     */
    public boolean inPackage() {
        return true;
    }

    /**
     * Will return false. The <code>@tagName</code> can't be used in type documentation.
     * @return true since <code>@tagName</code>
     * can be used in type documentation and false
     * otherwise.
     */
    public boolean inType() {
        return true;
    }

    /**
     * Will return false. The <code>@tagName</code>
     * is not an inline tag.
     * @return false since <code>@tagName</code>
     * is not an inline tag.
     */
    public boolean isInlineTag() {
        return false;
    }



    /**
     * Return the name of this custom tag.
     * @return name
     */
    public String getName() {
        return strName;
    }

    /**
     * Given the <code>Tag</code> representation of this custom
     * tag,return its string representation.
     * @param tag the <code>Tag</code> representation of this custom tag.
     * @return output format of tag text
     */
    public String toString(final Tag tag) {
        return tag.text();
    }

    /**
     * Given an array of <code>Tag</code>s representing this custom
     * tag, return its string representation.
     * @param tags  the array of <code>Tag</code>s representing of this custom tag.
     * @return output format of tag texts
     */
    public String toString(final Tag[] tags) {
        if (tags.length == 0) {
            return null;
        }
        String result = "";
        for (int i = 0; i < tags.length; i++) {
            result += toString(tags[i]);
        }
        return result;
    }
}
